# Generated by Django 3.2.13 on 2022-07-04 15:41

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("edc_pharmacy", "0006_historicalrxrefill_roundup_divisible_by_and_more"),
    ]

    operations = [
        migrations.AlterModelOptions(
            name="historicaldispensinghistory",
            options={
                "get_latest_by": ("history_date", "history_id"),
                "ordering": ("-history_date", "-history_id"),
                "verbose_name": "historical Dispensing history",
                "verbose_name_plural": "historical Dispensing history",
            },
        ),
        migrations.AlterModelOptions(
            name="historicaldosageguideline",
            options={
                "get_latest_by": ("history_date", "history_id"),
                "ordering": ("-history_date", "-history_id"),
                "verbose_name": "historical Dosage Guideline",
                "verbose_name_plural": "historical Dosage Guidelines",
            },
        ),
        migrations.AlterModelOptions(
            name="historicalformulation",
            options={
                "get_latest_by": ("history_date", "history_id"),
                "ordering": ("-history_date", "-history_id"),
                "verbose_name": "historical Formulation",
                "verbose_name_plural": "historical Formulations",
            },
        ),
        migrations.AlterModelOptions(
            name="historicallabels",
            options={
                "get_latest_by": ("history_date", "history_id"),
                "ordering": ("-history_date", "-history_id"),
                "verbose_name": "historical Label",
                "verbose_name_plural": "historical Labels",
            },
        ),
        migrations.AlterModelOptions(
            name="historicalmedication",
            options={
                "get_latest_by": ("history_date", "history_id"),
                "ordering": ("-history_date", "-history_id"),
                "verbose_name": "historical Medication",
                "verbose_name_plural": "historical Medications",
            },
        ),
        migrations.AlterModelOptions(
            name="historicalmedicationlot",
            options={
                "get_latest_by": ("history_date", "history_id"),
                "ordering": ("-history_date", "-history_id"),
                "verbose_name": "historical Medication lot",
                "verbose_name_plural": "historical Medication lots",
            },
        ),
        migrations.AlterModelOptions(
            name="historicalmedicationproduct",
            options={
                "get_latest_by": ("history_date", "history_id"),
                "ordering": ("-history_date", "-history_id"),
                "verbose_name": "historical Medication product",
                "verbose_name_plural": "historical Medication products",
            },
        ),
        migrations.AlterModelOptions(
            name="historicalmedicationstock",
            options={
                "get_latest_by": ("history_date", "history_id"),
                "ordering": ("-history_date", "-history_id"),
                "verbose_name": "historical Medication stock",
                "verbose_name_plural": "historical Medication stock",
            },
        ),
        migrations.AlterModelOptions(
            name="historicalmedicationstockcreatelabels",
            options={
                "get_latest_by": ("history_date", "history_id"),
                "ordering": ("-history_date", "-history_id"),
                "verbose_name": "historical Medication stock: Create labels",
                "verbose_name_plural": "historical Medication stock: Create labels",
            },
        ),
        migrations.AlterModelOptions(
            name="historicalmedicationstockreceiving",
            options={
                "get_latest_by": ("history_date", "history_id"),
                "ordering": ("-history_date", "-history_id"),
                "verbose_name": "historical Medication stock: Receiving",
                "verbose_name_plural": "historical Medication stock: Receiving",
            },
        ),
        migrations.AlterModelOptions(
            name="historicalreturnhistory",
            options={
                "get_latest_by": ("history_date", "history_id"),
                "ordering": ("-history_date", "-history_id"),
                "verbose_name": "historical Return history",
                "verbose_name_plural": "historical Return history",
            },
        ),
        migrations.AlterModelOptions(
            name="historicalrx",
            options={
                "get_latest_by": ("history_date", "history_id"),
                "ordering": ("-history_date", "-history_id"),
                "verbose_name": "historical Prescription",
                "verbose_name_plural": "historical Prescriptions",
            },
        ),
        migrations.AlterModelOptions(
            name="historicalrxrefill",
            options={
                "get_latest_by": ("history_date", "history_id"),
                "ordering": ("-history_date", "-history_id"),
                "verbose_name": "historical RX refill",
                "verbose_name_plural": "historical RX refills",
            },
        ),
        migrations.AlterField(
            model_name="historicaldispensinghistory",
            name="history_date",
            field=models.DateTimeField(db_index=True),
        ),
        migrations.AlterField(
            model_name="historicaldosageguideline",
            name="history_date",
            field=models.DateTimeField(db_index=True),
        ),
        migrations.AlterField(
            model_name="historicalformulation",
            name="history_date",
            field=models.DateTimeField(db_index=True),
        ),
        migrations.AlterField(
            model_name="historicallabels",
            name="history_date",
            field=models.DateTimeField(db_index=True),
        ),
        migrations.AlterField(
            model_name="historicalmedication",
            name="history_date",
            field=models.DateTimeField(db_index=True),
        ),
        migrations.AlterField(
            model_name="historicalmedicationlot",
            name="history_date",
            field=models.DateTimeField(db_index=True),
        ),
        migrations.AlterField(
            model_name="historicalmedicationproduct",
            name="history_date",
            field=models.DateTimeField(db_index=True),
        ),
        migrations.AlterField(
            model_name="historicalmedicationstock",
            name="history_date",
            field=models.DateTimeField(db_index=True),
        ),
        migrations.AlterField(
            model_name="historicalmedicationstockcreatelabels",
            name="history_date",
            field=models.DateTimeField(db_index=True),
        ),
        migrations.AlterField(
            model_name="historicalmedicationstockreceiving",
            name="history_date",
            field=models.DateTimeField(db_index=True),
        ),
        migrations.AlterField(
            model_name="historicalreturnhistory",
            name="history_date",
            field=models.DateTimeField(db_index=True),
        ),
        migrations.AlterField(
            model_name="historicalrx",
            name="history_date",
            field=models.DateTimeField(db_index=True),
        ),
        migrations.AlterField(
            model_name="historicalrxrefill",
            name="history_date",
            field=models.DateTimeField(db_index=True),
        ),
    ]
